===============================
Yasmine CLI
===============================

.. image:: https://img.shields.io/travis/mhagerty/yasmine-cli.svg
        :target: https://travis-ci.org/mhagerty/yasmine-cli

.. image:: https://img.shields.io/pypi/v/yasmine-cli.svg
        :target: https://pypi.python.org/pypi/yasmine-cli


Command line tool for editing StationXML files

* Free software: MIT license
* Documentation: (COMING SOON!) https://yasmine-cli.readthedocs.org.

Features
--------

* TODO
